AuthenticationError

Enum AuthenticationError 

#[non_exhaustive]
pub enum AuthenticationError { Identity, NotAuthoritative, StaleDate, Credential, Build, }
Authentication-service failure before an Identity field could be added.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Identity

From or To did not contain a canonical identity.



NotAuthoritative

Local policy does not authorize this service to assert the From identity.



StaleDate

Date is malformed or outside the freshness policy.



Credential

The signing credential is malformed or outside its validity interval.



Build

The finished header could not be built.