Power

Enum Power 

pub enum Power {
    Unconstrained,
    Constrained,
}
Whether the device is one where a keep-alive every two minutes is a battery problem (4.4.1).

Variants



Unconstrained

Mains, or a battery large enough not to care.



Constrained

A phone. 4.4.1 raises the interval by a factor of seven for these.