pub struct Publisher { /* private fields */ }Expand description
One sans-I/O publication lifecycle.
Implementations
Sourceimpl Publisher
impl Publisher
Sourcepub fn start(
config: Config,
start: Start,
) -> Result<(Self, Vec<Output>), StartError>
pub fn start( config: Config, start: Start, ) -> Result<(Self, Vec<Output>), StartError>
Start one initial publication.
Sourcepub fn entity_tag(&self) -> Option<&str>
pub fn entity_tag(&self) -> Option<&str>
Current entity tag after a successful operation.
Sourcepub fn granted_expiry(&self) -> Option<Duration>
pub fn granted_expiry(&self) -> Option<Duration>
Current granted expiry after a successful operation.
Sourcepub fn response(
&mut self,
response: Option<&Response>,
cnonce: &str,
) -> Vec<Output>
pub fn response( &mut self, response: Option<&Response>, cnonce: &str, ) -> Vec<Output>
Consume a final response; cnonce is fresh driver entropy for a possible digest retry.
Sourcepub fn modify(
&mut self,
body: Bytes,
content_type: String,
) -> Result<Vec<Output>, CommandError>
pub fn modify( &mut self, body: Bytes, content_type: String, ) -> Result<Vec<Output>, CommandError>
Replace event state conditionally.
Sourcepub fn remove(&mut self) -> Result<Vec<Output>, CommandError>
pub fn remove(&mut self) -> Result<Vec<Output>, CommandError>
Remove event state. At most one request is queued behind a live operation.
Sourcepub fn timer_fired(&mut self, timer: Timer, generation: u64) -> Vec<Output>
pub fn timer_fired(&mut self, timer: Timer, generation: u64) -> Vec<Output>
Fire one exact timer generation.
Sourcepub fn shutdown_deadline(&mut self) -> Vec<Output>
pub fn shutdown_deadline(&mut self) -> Vec<Output>
Force the bounded runtime shutdown deadline.