#[non_exhaustive]pub enum RegistrationObservationError {
MissingVia,
MalformedVia,
ContradictoryReceived,
ContradictoryRport,
MissingReceived,
MissingRport,
NonIpReceived,
InvalidRport,
}Expand description
Why a successful REGISTER response did not contain one usable path observation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
MissingVia
The successful response carried no Via header.
MalformedVia
The first Via header could not be parsed into a top hop.
ContradictoryReceived
The top hop asserted received more than once.
ContradictoryRport
The top hop asserted rport more than once.
MissingReceived
rport was present but received was absent.
MissingRport
received was present but rport was absent or valueless.
NonIpReceived
received was valueless or was not an IPv4 or IPv6 literal.
InvalidRport
rport was not a decimal port in 1..=65535.